@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::BehavioralBid;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -64,17 +67,25 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 Bid
 
-=over 8
+Gets/sets Bid (Bid)
 
-Bid (Bid)
-Id (long)
-Name (string)
-SegmentId (long)
-Status (BehavioralBidStatus)
+=head2 Id
 
-=back
+Gets/sets Id (long)
+
+=head2 Name
+
+Gets/sets Name (string)
+
+=head2 SegmentId
+
+Gets/sets SegmentId (long)
+
+=head2 Status
+
+Gets/sets Status (BehavioralBidStatus)
 
 =cut
 
