@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::Date;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -60,15 +63,17 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 Day
 
-=over 8
+Gets/sets Day (int)
 
-Day (int)
-Month (int)
-Year (int)
+=head2 Month
 
-=back
+Gets/sets Month (int)
+
+=head2 Year
+
+Gets/sets Year (int)
 
 =cut
 
