@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::EditorialError;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -66,18 +69,29 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 Appealable
 
-=over 8
+Gets/sets Appealable (boolean)
 
-Appealable (boolean)
-Code (int)
-DisapprovedText (string)
-ErrorCode (string)
-Index (int)
-Message (string)
+=head2 Code
 
-=back
+Gets/sets Code (int)
+
+=head2 DisapprovedText
+
+Gets/sets DisapprovedText (string)
+
+=head2 ErrorCode
+
+Gets/sets ErrorCode (string)
+
+=head2 Index
+
+Gets/sets Index (int)
+
+=head2 Message
+
+Gets/sets Message (string)
 
 =cut
 
