@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::GetKeywordsByEditorialStatusResponse;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -56,13 +59,9 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 Keywords
 
-=over 8
-
-Keywords (ArrayOfKeyword)
-
-=back
+Gets/sets Keywords (ArrayOfKeyword)
 
 =cut
 
