@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::Keyword;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -82,26 +85,61 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 BroadMatchBid
 
-=over 8
+Gets/sets BroadMatchBid (Bid)
 
-BroadMatchBid (Bid)
-CashBackInfo (CashBackInfo)
-ContentMatchBid (Bid)
-EditorialStatus (KeywordEditorialStatus)
-ExactMatchBid (Bid)
-Id (long)
-NegativeKeywords (ArrayOfstring)
-OverridePriority (OverridePriority)
-Param1 (string)
-Param2 (string)
-Param3 (string)
-PhraseMatchBid (Bid)
-Status (KeywordStatus)
-Text (string)
+=head2 CashBackInfo
 
-=back
+Gets/sets CashBackInfo (CashBackInfo)
+
+=head2 ContentMatchBid
+
+Gets/sets ContentMatchBid (Bid)
+
+=head2 EditorialStatus
+
+Gets/sets EditorialStatus (KeywordEditorialStatus)
+
+=head2 ExactMatchBid
+
+Gets/sets ExactMatchBid (Bid)
+
+=head2 Id
+
+Gets/sets Id (long)
+
+=head2 NegativeKeywords
+
+Gets/sets NegativeKeywords (ArrayOfstring)
+
+=head2 OverridePriority
+
+Gets/sets OverridePriority (OverridePriority)
+
+=head2 Param1
+
+Gets/sets Param1 (string)
+
+=head2 Param2
+
+Gets/sets Param2 (string)
+
+=head2 Param3
+
+Gets/sets Param3 (string)
+
+=head2 PhraseMatchBid
+
+Gets/sets PhraseMatchBid (Bid)
+
+=head2 Status
+
+Gets/sets Status (KeywordStatus)
+
+=head2 Text
+
+Gets/sets Text (string)
 
 =cut
 
