@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::MobileAd;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -66,24 +69,35 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 =head1 METHODS
 
+Remark: Inherited methods are not listed.
+
 =head2 new
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 BusinessName
 
-=over 8
+Gets/sets BusinessName (string)
 
-BusinessName (string)
-DestinationUrl (string)
-DisplayUrl (string)
-PhoneNumber (string)
-Text (string)
-Title (string)
+=head2 DestinationUrl
 
-Inherited attributes are not listed.
+Gets/sets DestinationUrl (string)
 
-=back
+=head2 DisplayUrl
+
+Gets/sets DisplayUrl (string)
+
+=head2 PhoneNumber
+
+Gets/sets PhoneNumber (string)
+
+=head2 Text
+
+Gets/sets Text (string)
+
+=head2 Title
+
+Gets/sets Title (string)
 
 =cut
 
