@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::RadiusTargetBid;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -62,16 +65,21 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 IncrementalBid
 
-=over 8
+Gets/sets IncrementalBid (IncrementalBidPercentage)
 
-IncrementalBid (IncrementalBidPercentage)
-LatitudeDegrees (double)
-LongitudeDegrees (double)
-Radius (int)
+=head2 LatitudeDegrees
 
-=back
+Gets/sets LatitudeDegrees (double)
+
+=head2 LongitudeDegrees
+
+Gets/sets LongitudeDegrees (double)
+
+=head2 Radius
+
+Gets/sets Radius (int)
 
 =cut
 
