@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::NotificationManagementService::EditorialRejectionNotification;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -106,44 +109,115 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 =head1 METHODS
 
+Remark: Inherited methods are not listed.
+
 =head2 new
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 AccountId
 
-=over 8
+Gets/sets AccountId (int)
 
-AccountId (int)
-AccountName (string)
-AccountNumber (string)
-AdDescription (string)
-AdId (int)
-AdTitle (string)
-CampaignId (int)
-CampaignName (string)
-CustomerName (string)
-DestinationURL (string)
-DisplayURL (string)
-KeywordsAccepted (int)
-KeywordsPending (int)
-KeywordsRejected (int)
-OrderId (int)
-OrderName (string)
-Top1Keyword (string)
-Top1KeywordReason (string)
-Top2Keyword (string)
-Top2KeywordReason (string)
-Top3Keyword (string)
-Top3KeywordReason (string)
-Top4Keyword (string)
-Top4KeywordReason (string)
-Top5Keyword (string)
-Top5KeywordReason (string)
+=head2 AccountName
 
-Inherited attributes are not listed.
+Gets/sets AccountName (string)
 
-=back
+=head2 AccountNumber
+
+Gets/sets AccountNumber (string)
+
+=head2 AdDescription
+
+Gets/sets AdDescription (string)
+
+=head2 AdId
+
+Gets/sets AdId (int)
+
+=head2 AdTitle
+
+Gets/sets AdTitle (string)
+
+=head2 CampaignId
+
+Gets/sets CampaignId (int)
+
+=head2 CampaignName
+
+Gets/sets CampaignName (string)
+
+=head2 CustomerName
+
+Gets/sets CustomerName (string)
+
+=head2 DestinationURL
+
+Gets/sets DestinationURL (string)
+
+=head2 DisplayURL
+
+Gets/sets DisplayURL (string)
+
+=head2 KeywordsAccepted
+
+Gets/sets KeywordsAccepted (int)
+
+=head2 KeywordsPending
+
+Gets/sets KeywordsPending (int)
+
+=head2 KeywordsRejected
+
+Gets/sets KeywordsRejected (int)
+
+=head2 OrderId
+
+Gets/sets OrderId (int)
+
+=head2 OrderName
+
+Gets/sets OrderName (string)
+
+=head2 Top1Keyword
+
+Gets/sets Top1Keyword (string)
+
+=head2 Top1KeywordReason
+
+Gets/sets Top1KeywordReason (string)
+
+=head2 Top2Keyword
+
+Gets/sets Top2Keyword (string)
+
+=head2 Top2KeywordReason
+
+Gets/sets Top2KeywordReason (string)
+
+=head2 Top3Keyword
+
+Gets/sets Top3Keyword (string)
+
+=head2 Top3KeywordReason
+
+Gets/sets Top3KeywordReason (string)
+
+=head2 Top4Keyword
+
+Gets/sets Top4Keyword (string)
+
+=head2 Top4KeywordReason
+
+Gets/sets Top4KeywordReason (string)
+
+=head2 Top5Keyword
+
+Gets/sets Top5Keyword (string)
+
+=head2 Top5KeywordReason
+
+Gets/sets Top5KeywordReason (string)
 
 =cut
 
