@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::NotificationManagementService::Notification;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -64,17 +67,25 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 CustomerId
 
-=over 8
+Gets/sets CustomerId (int)
 
-CustomerId (int)
-NotificationDate (dateTime)
-NotificationType (NotificationType)
-RecipientEmailAddress (string)
-UserLocale (string)
+=head2 NotificationDate
 
-=back
+Gets/sets NotificationDate (dateTime)
+
+=head2 NotificationType
+
+Gets/sets NotificationType (NotificationType)
+
+=head2 RecipientEmailAddress
+
+Gets/sets RecipientEmailAddress (string)
+
+=head2 UserLocale
+
+Gets/sets UserLocale (string)
 
 =cut
 
