@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::ReportingService::BudgetSummaryReportTime;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -62,16 +65,21 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 CustomDateRangeEnd
 
-=over 8
+Gets/sets CustomDateRangeEnd (Date)
 
-CustomDateRangeEnd (Date)
-CustomDateRangeStart (Date)
-CustomDates (ArrayOfDate)
-PredefinedTime (BudgetSummaryReportTimePeriod)
+=head2 CustomDateRangeStart
 
-=back
+Gets/sets CustomDateRangeStart (Date)
+
+=head2 CustomDates
+
+Gets/sets CustomDates (ArrayOfDate)
+
+=head2 PredefinedTime
+
+Gets/sets PredefinedTime (BudgetSummaryReportTimePeriod)
 
 =cut
 
